import * as React from 'react';
import clsx from 'clsx';
import { withStyles } from '@material-ui/core/styles';
import Button , { ButtonProps } from '@material-ui/core/Button';

const color = {
  primaryColor :' #31AFC4',
  blackColor : 'black',
  whiteColor : '#fff',
  disableBackgroundColor: '#BDC3CA',
  disableColor: '#787D82',
  hoverBackgroundColor : '#2590A2',
};


const styles = {
contained: {
    color: color.whiteColor,
    backgroundColor: color.primaryColor,
    '&:hover' : {
      backgroundColor: color.hoverBackgroundColor,
    },
    '&$disabled': {
      color: color.disableBackgroundColor,
      backgroundColor : color.disableColor
    },
  },
text: {
    color: color.primaryColor,
    backgroundColor: 'transparent',
    border: '1px solid transparent',
    '&:hover' : {
      border: '1px solid'+color.primaryColor,
      backgroundColor: 'transparent',
      },
    '&$disabled': {
      color: color.disableBackgroundColor,
      backgroundColor : color.disableColor
    },
  },
  outlined: {
    color: color.primaryColor,
    border: '1px solid' + color.primaryColor,
    '&:hover' : {
      border: '1px solid'+color.primaryColor,
      backgroundColor: 'transparent',
      },
  },
  checked: {}
};

interface Props extends ButtonProps { 
  children?: React.ReactNode;
  className?: string;
  disableElevation?: boolean;
  disableFocusRipple?: boolean;
  endIcon?: React.ReactNode;
  fullWidth?: boolean;
  href?: string;
  size?: 'small' | 'medium' | 'large';
  startIcon?: React.ReactNode;
  variant?: 'text' | 'outlined' | 'contained';
}

function MuiButton(props: Props) {
  const {children, className, ...other } = props;

  return (
    <Button className={clsx(className )} {...other}>
      {children || 'class names'}
    </Button>
  );
}

export default withStyles(styles)(MuiButton);
