import * as React from 'react';
import clsx from 'clsx';
import { withStyles } from '@material-ui/core/styles';
import Checkbox, { CheckboxProps } from '@material-ui/core/Checkbox';

const color = {
  primaryColor :' #31AFC4',
  disableBackgroundColor: '#BDC3CA',
  disableColor: '#787D82',
  hoverBackgroundColor : '#e8f7fa',
};

const styles = {
  root: {
    color: color.primaryColor,
    '&$checked': {
      color: color.primaryColor,
    },
    '&:hover' : {
      backgroundColor: color.hoverBackgroundColor,
    },
    '&$disabled': {
      color: color.disableColor,
    },
  },
  colorPrimary: {
    color: color.primaryColor,
    '&$checked': {
      color: color.primaryColor,
    },
    '&:hover' : {
      backgroundColor: color.hoverBackgroundColor,
    },
    '&$disabled': {
      color: color.disableColor,
    },
  },
  checked: {}
};

interface Props extends CheckboxProps {
  children?: React.ReactNode;
  className?: string;
  value?: string;
  size ?: "small" | "medium" | undefined
  color ?: "primary" | "secondary" | "default" | undefined
   checkedIcon?: React.ReactNode;
  icon?: React.ReactNode;
  indeterminate?: boolean;
  indeterminateIcon?: React.ReactNode;
}

function MuiCheckbox(props: Props) {
  const {children, className, ...other } = props;

  return <Checkbox className={clsx(className)} {...other}>
    {props.children}
  </Checkbox>
};

export default withStyles(styles)(MuiCheckbox);
