import * as React from 'react';
import clsx from 'clsx';
import { withStyles } from '@material-ui/core/styles';
import Fab, { FabProps } from '@material-ui/core/Fab';

const color = {
  primaryColor :' #31AFC4',
  blackColor : 'black',
  whiteColor : '#fff',
  disableBackgroundColor: '#BDC3CA',
  disableColor: '#787D82',
  hoverBackgroundColor : '#2590A2',
};

interface Props extends FabProps {
  size?: 'small' | 'medium' | 'large';
  variant?: 'round' | 'extended';
  href?: string;
  disabled?: boolean;
  children?: React.ReactNode;
  className?: string;
  disableFocusRipple?: boolean;
}

const styles = {
  root: {
    opacity: '1',
    color: color.whiteColor,
    backgroundColor: color.primaryColor,
    '&:hover' : {
    backgroundColor: color.hoverBackgroundColor,
    },
    '&$disabled': {
      color: color.disableBackgroundColor,
      backgroundColor : color.disableColor,
    },
  },
  checked: {}
};

function MuiFab(props: Props) {
  const { children, className, ...other } = props;
  return (
    <Fab className={clsx(className )} {...other}>
      {children || 'class names'}
    </Fab>
  );
}

export default withStyles(styles)(MuiFab);
