import * as React from 'react';
import clsx from 'clsx';
import { withStyles } from '@material-ui/core/styles';
import Radio , { RadioProps } from '@material-ui/core/Radio';

const color = {
  primaryColor :'#31AFC4',
  disableColor: '#BDC3CA',
  hoverBackgroundColor : '#e8f7fa',
};

interface Props extends RadioProps {
  children?: React.ReactNode;
  className?: string;
  checkedIcon?: React.ReactNode;
  color?: 'primary' | 'secondary' | 'default';
  icon?: React.ReactNode;
  size?: 'small' | 'medium';
  
}

const styles = {
  root: {
    opacity: '1',
    color: color.primaryColor,
    '&$checked': { color: color.primaryColor },
    '&$disabled': { color: color.disableColor },
    '&:hover' : {backgroundColor: color.hoverBackgroundColor, },
  },
  colorPrimary: {
    color: color.primaryColor,
    '&$checked': {
      color: color.primaryColor,
      '&$disabled': {color: color.disableColor},
    },
    '&:hover' : {backgroundColor: color.hoverBackgroundColor, },
  },
  colorSecondary: {
    color: color.primaryColor,
    '&$checked': { color: color.primaryColor},
    '&$disabled': { color: color.disableColor },
    '&:hover' : {backgroundColor: color.hoverBackgroundColor, },
  },
  checked: {}
};


function MuiRadio(props: Props) {
  const { children, className, ...other } = props;
  return (
    <Radio className={clsx(className)} {...other}>   
    { props.children }
    </Radio>
  );
}

export default withStyles(styles)(MuiRadio);