import * as React from 'react';
import './index.scss';
import Collapse from '@material-ui/core/Collapse';
import { NavLink } from 'react-router-dom';

interface INavigationItem {
  component?: React.ReactNode;
  note?: string;
  children?: INavigationItem[];
  label?: string;
  icon?: string;
  link?: string;
}

interface INavigationOptionsListProps {
  componentList: INavigationItem;
  depth?: number;
  depthStep?: number;
  prevComponent?: INavigationItem;
}

interface INavigationListOptionsProps {
  componentList: INavigationItem[];
  depth?: number;
  depthStep?: number;
}

const NavigationTabsOptions: React.FunctionComponent<INavigationOptionsListProps> = props => {
  const { componentList, prevComponent, depth = 0, depthStep = 15 } = props;

  const { children, component, label, icon } = componentList;

  const [tabs, setTabs] = React.useState(false);

  const toggleTabs = () => {
    setTabs(prevValue => !prevValue);
  };

  const onClickSubMenuTabs = () => {
    if (Array.isArray(children)) {
      toggleTabs();
    }
  };
  return (
    <>
      <ul className='menu-list-none-style'>
        <li style={{ paddingTop: '10px', paddingBottom: '10px' }}>
          <div
            className='font-weight-button'
            style={{
              width: '100%',
              paddingLeft: 3 * 15 + 'px',
              paddingRight: '15px',
              display: 'flex',
              justifyContent: 'space-between',
              cursor: 'pointer',
              fontSize: '16px'
            }}
            onClick={onClickSubMenuTabs}
          >
            <div
              style={{
                width: '100%',
                display: 'flex',
                fontSize: '16px'
              }}
            >
              {component ? (
                component
              ) : (
                <>
                  <div style={{ display: 'flex', width: '100%' }}>
                    <i className='material-icons' style={{ paddingRight: '10px' }}>
                      {icon}
                    </i>
                    <span>{label}</span>
                  </div>
                </>
              )}
            </div>
            <i className='arrow-up  material-icons'>keyboard_arrow_right</i>
          </div>
        </li>
      </ul>
      <div className={tabs ? 'navigation-menu-with-transform' : 'navigation-menu-without-transform'}>
        <ul className='menu-list-none-style'>
          <ul className='menu-list-none-style'>
            <li style={{ paddingTop: '6px', paddingBottom: '6px', backgroundColor: 'rgba(0, 0, 0, 0.08)' }}>
              <div
                className='font-weight-button'
                style={{
                  width: '100%',
                  paddingLeft: '17px',
                  paddingRight: '15px',
                  display: 'flex',
                  cursor: 'pointer',
                  fontSize: '16px'
                }}
                onClick={onClickSubMenuTabs}
              >
                <i style={{ paddingRight: '10px' }} className='arrow-up  material-icons'>
                  arrow_back
                </i>
                {prevComponent!.component ? (
                  prevComponent!.component
                ) : (
                  <>
                    <div style={{ display: 'flex', width: '100%' }}>
                      <span>{prevComponent!.label}</span>
                    </div>
                  </>
                )}
              </div>
            </li>
          </ul>
          {Array.isArray(children) ? (
            <>
              {children.map((subItem: INavigationItem) => {
                return (
                  <>
                    {subItem.children && subItem.children.length > 0 ? (
                      <>
                        <NavigationOptionsList componentList={subItem} depth={depth + 1} depthStep={depthStep} />
                      </>
                    ) : (
                      <>
                        <ul className='menu-list-none-style'>
                          <li style={{ paddingTop: '10px', paddingBottom: '10px' }}>
                            <div
                              className='font-weight-button'
                              style={{
                                width: '100%',
                                paddingLeft: 1 * 15 + 'px',
                                paddingRight: '15px',
                                display: 'flex',
                                cursor: 'pointer',
                                justifyContent: 'space-between',
                                fontSize: '16px'
                              }}
                            >
                              <div
                                style={{
                                  width: '100%',
                                  display: 'flex',
                                  fontSize: '16px'
                                }}
                              >
                                {subItem.component ? (
                                  subItem.component
                                ) : (
                                  <>
                                    <NavLink to={subItem.link!} activeClassName='wfr-active' style={{ display: 'flex', textDecoration: 'none' }}>
                                      <i className='material-icons' style={{ paddingRight: '10px' }}>
                                        {subItem.icon}
                                      </i>
                                      <span>{subItem.label}</span>
                                    </NavLink>
                                  </>
                                )}
                              </div>
                            </div>
                          </li>
                        </ul>
                      </>
                    )}
                  </>
                );
              })}
            </>
          ) : null}
        </ul>
      </div>
    </>
  );
};

const NavigationOptionsList: React.FunctionComponent<INavigationOptionsListProps> = props => {
  const { componentList, depth = 0, depthStep = 15 } = props;
  const { component, children, label, icon } = componentList;
  const [collapsed, setCollapsed] = React.useState(true);

  const toggleCollapse = () => {
    setCollapsed(prevValue => !prevValue);
  };

  const onClickSubMenu = () => {
    if (Array.isArray(children)) {
      toggleCollapse();
    }
  };

  return (
    <>
      <ul className='menu-list-none-style'>
        <li style={{ paddingTop: '10px', paddingBottom: '10px' }}>
          <div
            className={collapsed ? 'font-weight-button' : 'font-weight-button-bold'}
            style={{
              width: '100%',
              paddingLeft: depth * depthStep + 'px',
              paddingRight: '15px',
              display: 'flex',
              justifyContent: 'space-between',
              cursor: 'pointer',
              fontSize: '16px'
            }}
            onClick={onClickSubMenu}
          >
            <div
              style={{
                width: '100%',
                display: 'flex',
                fontSize: '16px'
              }}
            >
              {component ? (
                component
              ) : (
                <>
                  <div style={{ display: 'flex', width: '100%' }}>
                    <i className='material-icons' style={{ paddingRight: '10px' }}>
                      {icon}
                    </i>
                    <span>{label}</span>
                  </div>
                </>
              )}
            </div>
            <i className='arrow-up  material-icons'>{collapsed ? 'keyboard_arrow_down' : 'keyboard_arrow_up'}</i>
          </div>
        </li>
        <Collapse in={!collapsed} timeout='auto' unmountOnExit>
          {Array.isArray(children) ? (
            <>
              {children.map((subItem: INavigationItem) => {
                console.log('data subItem', subItem.children?.length);
                if (subItem.note === 'newTabs') {
                  return <NavigationTabsOptions componentList={subItem} prevComponent={subItem} />;
                } else if (subItem.children && subItem.children.length > 0) {
                  return <NavigationOptionsList depth={depth + 1} depthStep={depthStep} componentList={subItem} />;
                } else {
                  return (
                    <>
                      <li style={{ paddingTop: '10px', paddingBottom: '10px' }}>
                        <div
                          className='font-weight-button'
                          style={{
                            width: '100%',
                            justifyContent: 'space-between',
                            paddingLeft: 2 * 15 + 'px',
                            paddingRight: '15px',
                            display: 'flex',
                            cursor: 'pointer',
                            fontSize: '16px'
                          }}
                        >
                          <div
                            style={{
                              width: '100%',
                              display: 'flex',
                              fontSize: '16px'
                            }}
                          >
                            {subItem.component ? (
                              subItem.component
                            ) : (
                              <>
                                <NavLink to={subItem.link!} activeClassName='wfr-active' style={{ display: 'flex', textDecoration: 'none' }}>
                                  <i className='material-icons' style={{ paddingRight: '10px' }}>
                                    {subItem.icon}
                                  </i>
                                  <span>{subItem.label}</span>
                                </NavLink>
                              </>
                            )}
                          </div>
                        </div>
                      </li>
                    </>
                  );
                }
              })}
            </>
          ) : null}
        </Collapse>
      </ul>
    </>
  );
};

const NavigationComponent: React.FunctionComponent<INavigationListOptionsProps> = props => {
  const { componentList, depth = 0, depthStep = 15 } = props;
  return (
    <>
      <div className='sidenav-content'>
        {componentList.map((sidebaritems: INavigationItem) => {
          return (
            <>
              {sidebaritems.children && sidebaritems.children.length > 0 ? (
                <>
                  <NavigationOptionsList depth={depth! + 1} depthStep={depthStep} componentList={sidebaritems} />
                </>
              ) : (
                <>
                  <ul className='menu-list-none-style'>
                    <li style={{ paddingTop: '10px', paddingBottom: '10px' }}>
                      <div
                        className='font-weight-button'
                        style={{
                          width: '100%',
                          paddingLeft: 1 * 15 + 'px',
                          paddingRight: '15px',
                          display: 'flex',
                          cursor: 'pointer',
                          justifyContent: 'space-between',
                          fontSize: '16px'
                        }}
                      >
                        <div
                          style={{
                            width: '100%',
                            display: 'flex',
                            fontSize: '16px'
                          }}
                        >
                          {sidebaritems.component ? (
                            sidebaritems.component
                          ) : (
                            <>
                              <NavLink to={sidebaritems.link!} activeClassName='wfr-active' style={{ display: 'flex', textDecoration: 'none' }}>
                                <i className='material-icons' style={{ paddingRight: '10px' }}>
                                  {sidebaritems.icon}
                                </i>
                                <span>{sidebaritems.label}</span>
                              </NavLink>
                            </>
                          )}
                        </div>
                      </div>
                    </li>
                  </ul>
                </>
              )}
            </>
          );
        })}
      </div>
    </>
  );
};

export default NavigationComponent;
